pub enum ProduceLimitError<E> {
Inner(E),
LimitReached,
}Expand description
An error emitted when a producer is tasked to produce at most some number of items, but instead produces a higher number of items.
E is the Error type of the producer
Counterpart: the ConsumeLimitError type.
Variants